'''
Created on Aug 23, 2010

@author: Dummey
'''
import pyglet
import math
import random

NORTH = 270
WEST = 180
SOUTH = 90
EAST = 0

cop_images = [pyglet.image.load("data/cop.png"), pyglet.image.load("data/cop2.png")]
for image in cop_images:
    image.anchor_x = image.width / 2
    image.anchor_y = image.height / 2
cop_batch = pyglet.graphics.Batch()

speeds = [1, 2, 3, 4, 5, 10, 20, 60]

class Cops():
    
    def __init__(self):
        global cop_batch
        cop_batch = pyglet.graphics.Batch()
        self.cops = []
        
    def add_cop(self, x = 400, y = 90):
        self.cops.append(Cop(x, y, cop_batch))
        
    def get_cops(self):
        return self.cops
        
    def update(self):
        for cop in self.cops:
            cop.update()
        
    def on_draw(self):
        cop_batch.draw()

    
class Cop(pyglet.sprite.Sprite):
    
    def __init__(self, x, y, batch, speed = None):
        pyglet.sprite.Sprite.__init__(self, random.choice(cop_images), batch=batch)
        
        self.x = x
        self.y = y
        if speed is None:
            self.target_speed = speeds[0]
        else:
            self.target_speed = speed
        self.speed = 1.0
        self.chase = False
        self.image_state = 0
        self.target = None
        self.old_speed = self.speed
        self.change_direction(0)
    
    def update(self):
        if self.chase:
            self.siren()
        self.speed += (self.target_speed - self.speed)
        self.y += int(self.speed * math.sin(self.direction) * -1)
        self.x += int(self.speed * math.cos(self.direction))

    def change_direction(self, new_dir):
        if self.target:
            target_x = self.target.x - self.x
            target_y = self.target.y - self.y
            
            if abs(target_x) > abs(target_y):
                if target_x > 0:
                    self.rotation = EAST
                else:
                    self.rotation = WEST
            else:
                if target_y > 0:
                    self.rotation = NORTH
                else:
                    self.rotation = SOUTH
        else:
            self.rotation = new_dir
            
        self.direction = math.radians(self.rotation)
        
    def start_chase(self, target=None):
        self.chase = True
        try:
            self.target_speed = target.speed
        except:
            pass
        self.target = target
        pyglet.clock.schedule_once(self.stop_chase, 5)
            
    def stop_chase(self, dt=0):
        self.chase = False
        self.target = None
        
    def toggle_chase(self):
        if self.chase:
            self.stop_chase()
        else:
            self.start_chase()
        
    def siren(self):
        self.image_state = (self.image_state + 1) % len(cop_images)
        self.image = cop_images[self.image_state]
            
    def in_sight(self, x, y, range = 60):
        return self.intersects(x, y, range=60)
    
    def in_range(self, x, y, range=5):
        return self.intersects(x, y, range=5)
    
    def intersects(self, x, y, range=1):
        if abs(self.x - x) < self.speed + range*2 and abs(self.y - y) < self.speed + range*2:
            return True
        else:
            return False
    
    def on_draw(self):
        self.draw()
    