'''
Created on Aug 23, 2010

@author: Dummey
'''
import pyglet
import math
import random

hipster_image = [pyglet.image.load("data/lead_hipster.png")]

speeds = [1, 2, 3, 4, 5, 6, 7, 8, 9]
    
class LeadHipster(pyglet.sprite.Sprite):
    speedup_distance = 5
    target_direction = -1
    
    def __init__(self, x, y, speed = 1):
        pyglet.sprite.Sprite.__init__(self, random.choice(hipster_image))
        self.image.anchor_x = self.image.width / 2
        self.image.anchor_y = self.image.height / 2
        self.straights = 0
        self.target_direction = 0
        self.x = x
        self.y = y
        self.speed_setting = speed
        if speed is None:
            self.speed = speeds[self.speed_setting]
        else:
            self.speed = speed
        self.followers = {}
        
        self.label = pyglet.text.Label(str(len(self.followers)),
                      font_name='Segoe Script',
                      font_size=12,
                      x=self.x, y=self.y,
                      height = 50,
                      width = 100,
                      anchor_x='center',
                      anchor_y='center')

    def update(self):
        if self.straights >= self.speedup_distance and self.speed_setting + 1 < len(speeds):
            self.straights = 0
            self.speed_setting += 1
            self.speed = speeds[self.speed_setting]
            
        self.y += self.speed * math.sin(self.direction) * -1
        self.x += self.speed * math.cos(self.direction)
        
        for follower in self.followers:
            follower.x = self.x + self.followers[follower][0]
            follower.y = self.y + self.followers[follower][1]
            follower.speed = self.speed

            
        self.label.text = str(len(self.followers))
        self.label.x = self.x
        self.label.y = self.y

    def add_follower(self, hipster):
        if hipster not in self.followers:
            self.followers[hipster] = (random.randint(-10, 10), random.randint(-10, 10))

    def change_direction(self, new_dir):
        if self.target_direction not in new_dir:
            self.target_direction = random.choice(new_dir)
        if self.rotation == self.target_direction:
            self.straights += 1
        self.rotation = self.target_direction
        self.direction = math.radians(self.rotation)
        
        for follower in self.followers:
            try:
                follower.change_direction(self.rotation)
            except:
                pass
        
    def intersects(self, x, y, range = 1):
        if abs(self.x - x) < self.speed + range*2 and abs(self.y - y) < self.speed + range*2:
            return True
        else:
            return False
        
    def die(self):
        self.delete()
    
    def on_draw(self):
        self.draw()
        self.label.draw()